__version__ = '2021.12.5'

def version():
    """Version Print"""
    print(__version__)
